@@ -457,6 +457,15 @@ class Lattice(object):
         return Lattice(self._lll_matrix_mappings[delta][0])
 
 
+def lattice_coords_transformer(
+    old_lattice_mat=[], new_lattice_mat=[], cart_coords=[]
+):
+    """Transform coords to a new lattice."""
+    M = np.linalg.solve(new_lattice_mat, old_lattice_mat)
+    new_cart_coords = np.dot(cart_coords, M)
+    return new_cart_coords
+
+
 """
 if __name__ == "__main__":
 
